pub struct TrustStore { /* private fields */ }Expand description
Container for root certificates able to provide a root-of-trust for connection authentication
Platform native root certificates are enabled by default. To start with a clean trust store use TrustStore::empty
Implementations
Sourceimpl TrustStore
impl TrustStore
Sourcepub fn with_native_roots(self, enable_native_roots: bool) -> Self
pub fn with_native_roots(self, enable_native_roots: bool) -> Self
Enable or disable using the platform’s native trusted root certificate store
Default: true
Sourcepub fn with_pem_certificate(self, pem_bytes: impl Into<Vec<u8>>) -> Self
pub fn with_pem_certificate(self, pem_bytes: impl Into<Vec<u8>>) -> Self
Add the PEM encoded certificate to the trust store
This may be called more than once to add multiple certificates. NOTE: PEM certificate contents are not validated until passed to the configured TLS provider.
Sourcepub fn add_pem_certificate(
&mut self,
pem_bytes: impl Into<Vec<u8>>,
) -> &mut Self
pub fn add_pem_certificate( &mut self, pem_bytes: impl Into<Vec<u8>>, ) -> &mut Self
Add the PEM encoded certificate to the trust store
This may be called more than once to add multiple certificates. NOTE: PEM certificate contents are not validated until passed to the configured TLS provider.